#ifndef _ASR_H_
#define _ASR_H_
// Define los registros especificos de aplicacion de la tarjeta ZR36120

#define	HVIDEOCONTROL_ADR          0x000
#define	VVIDEOCONTROL_ADR          0x004
#define	OUTVIDEOCONTROL_ADR  	   0x008
#define	ADRTOPVIDEO_ADR		   0x00c
#define	ADRBOTTOMVIDEO_ADR	   0x010
#define	STRIDEGRABCONTROL_ADR	   0x014
#define	VIDEOCONTROL_ADR	   0x018
#define	ADRTOPVIDEOMASKMAP_ADR	   0x01c
#define	ADRBOTTOMVIDEOMASKMAP_ADR  0x020
#define	OVERLAYCONTROL_ADR	   0x024
#define	SYSPCICONTROL_ADR	   0x028
#define	GENPURPOSE_ADR		   0x02c
#define	CODESOURCE_ADR		   0x030
#define	CODETRANSFERCONTROLE_ADR   0x034
#define	CODEMEMORY_ADR		   0x038
#define	IRQSTATUS_ADR		   0x03c
#define	IRQCONTROL_ADR		   0x040
#define	I2CCONTROL_ADR		   0x044
// POSTOFFICE REGISTERS 0x200-0x2ff

typedef	struct
{
 unsigned  HEnd   : 10, //  9: 0 [ 0x3ff] RW horizontal end offset from HSYNC
	   HStart : 10, // 19:10 [ 0x001] RW horizontal start off. from HSYNC
	   r0     : 10, // 29:20 [ 0x000] R  reserved
	   HSPol  :  1, // 30:30 [    0b] RW 0=HSYNC polarity positive
	   r1     :  1; // 31:31 [    0b] R  reserved
} HVIDEOCONTROL;

typedef	struct
{
 unsigned  VEnd	  : 10,	//  9: 0 [ 0x3ff] RW vertical end offset from VSYNC
	   VStart : 10,	// 19:10 [ 0x001] RW vertical start offset from VSYNC
	   r0	  : 10,	// 29:20 [ 0x000] R  reserved
	   VSPol  :  1,	// 30:30 [    0b] RW 0=VSYNC polarity positive
	   r1	  :  1;	// 31:31 [    0b] R  reserved
} VVIDEOCONTROL;
typedef	struct
{
 unsigned  LittleEndian	:  1,	//  0: 0 [    1b] RW 1=Little Endian Pixel Format
	   Pack24	:  1,	//  1: 1 [    0b] RW 0=RGB 24 bits 3 PCI cycle, 1=1DWORD
	   ErrDif	:  1,	//  2: 2 [    0b] RW Error Diffusion 1=active for 555/565
	   YUV2RGB	:  2,	//  4: 3 [   10b] RW 0=YUV 01=RGB888 10=RGB565 11=RGB555
	   r0		:  1,	//  5: 5 [    0b] R  reserved
	   DispMod	:  1,	//  6: 6 [    0b] RW Display Mode.
				//		     0=emulated interlaced video 1=single field
	   r1		:  1,	//  7: 7 [    0b] R  reserved
	   VerDcm	:  6,	// 13: 8 [  0x00] RW Vertical Decimation Ratio. per 64 dropped pixel
	   HorDcm	:  6,	// 19:14 [  0x00] RW Horizontal Decimation Ratio. per 64 dropped pixel
	   DupFld	:  1,	// 20:20 [    0b] RW Duplicate Field. 1=top/bottom field duplicated
	   HFilter	:  3,	// 23:21 [  000b] RW 000=no luminance, 3 tap chrominace
				// 		     001=3 tap luminance, 3 tap chrominace
				// 		     010=4 tap luminance, 4 tap chrominace
				// 		     011=5 tap luminance, 4 tap chrominace
				// 		     100=4 tap luminance, 4 tap chrominace
				// 		     101-111=no luminance, 3 tap chrominace
	   VCLKPol	:  1,	// 24:24 [    0b] RW Video Clock polarity
	   TopField	:  1,	// 25:25 [    1b] RW Top Field Interpretation.
				//		    if ExtFI
				//			0=FI low:top field 1=FI high=top field
				//		    if internal
				//			0=HSYNC low:top field 1=HSYNC high=top field
	   ExtFI	:  1,	// 26:26 [    0b] RW External Field Indication. 0=HSYNC/VSYNC, 1=extern
	   r2		:  5;	// 31:27 [  0x00] R  reserved
} OUTVIDEOCONTROL;

typedef	dword	ADRTOPVIDEO;	// bits 0:1 hardwired to 0
typedef	dword	ADRBOTTOMVIDEO;	// bits 0:1 hardwired to 0
typedef	struct
{
 unsigned  FrameGrab	:  1,	//  0: 0 [    0b] RS Frame Grabbing Command/Status
	   SnapShot	:  1,	//  1: 1 [    0b] RW 1=Frame Grabbing Mode 0=Continuous Mode
	   r0		:  6,	//  7: 2 [  0x00] R  reserved
	   VidOvf	:  1,	//  8: 8 [    0b] RC 1=Internal pixel buffer overflow
				//		     cleared by writing 1 in it
	   r1		:  7,	// 15: 9 [  0x00] R  reserved
	   DispStride	: 16;	// 15: 9 [0xFFFC] R  Display Stride. incr in bytes to next line.
				//		     bits 0:1 hardwired to 0
} STRIDEGRABCONTROL;

typedef	struct
	{
	unsigned	VidWinWid	: 10,	//  9: 0 [ 0x3ff] RW Video Window Width in pixel
			r0		:  2,	// 11:10 [   00b] R  reserved
			VidWinHt	: 10,	// 21:12 [ 0x0f0] RW Video Window Height in lines
						//		     if DispMod=0 VidWinHt is half the number
			r1		:  2,	// 23:22 [   00b] R  reserved
			TriCom		:  1,	// 24:24 [    ?b] RW Triton Compatibility. 1 if 82437FX
						//		     what does intel messed up? :)
			MinPix		:  6,	// 30:25 [  0x07] RW Pixel FIFO Threshold, 0x01 to 0x1e
			VidEn		:  1;	// 31:31 [    1b] RW Video Enable.
	}	VIDEOCONTROL;
typedef	dword	ADRTOPVIDEOMASKMAP;	// bits 0:1 hardwired to 0, top field hardware mask table addr
typedef	dword	ADRBOTTOMVIDEOMASKMAP;	// bits 0:1 hardwired to 0, bottom field hardware mask table addr
typedef	struct
	{
	unsigned	MaskStride	:  8,	//  7: 0 [  0xff] RW MaskStride. incr in DWORD to the next line
			r0		:  7,	// 14: 8 [  0x00] R  reserved
			OvlEnable	:  1,	// 15:15 [    0b] RW OverLay Enable
			r1		: 16;	// 31:16 [0x0000] R  reserved
	}	OVERLAYCONTROL;
typedef	struct
	{
	unsigned	GenPurDir	:  8,	//  7: 0 [  0xff] RW General Purpose Pins Direction 1=input 0=ouput
			r0		:  8,	// 15: 8 [  0x00] R  reserved
			WaitState	:  3,	// 18:16 [  000b] RW PCI Wait State Control
			r1		:  5,	// 23:19 [  0x00] R  reserved
			SoftReset	:  1,	// 24:24 [  000b] RW Software Reset 0= reset all register to default.
			r2		:  7;	// 31:25 [  0x00] R  reserved
	}	SYSPCICONTROL;
typedef	struct
	{
	unsigned	RecTime0	:  2,	//  1: 0 [   00b] RW Recovery Time for Guest 0
						//		     00b 3 PCI CLK 01b 4 PCI CLK
						//		     10b 12 PCI CLK 11b 15 PCI CLK
			DurTime0	:  2,	//  3: 2 [   00b] RW Duration Time for Guest 0 same as above
			RecTime1	:  2,	//  5: 4 [   00b] RW Recovery Time for Guest 1 same as above
			DurTime1	:  2,	//  7: 6 [   00b] RW Duration Time for Guest 1 same as above
			RecTime2	:  2,	//  9: 8 [   00b] RW Recovery Time for Guest 1 same as above
			DurTime2	:  2,	// 11:10 [   00b] RW Duration Time for Guest 1 same as above
			RecTime3	:  2,	// 13:12 [   00b] RW Recovery Time for Guest 1 same as above
			DurTime3	:  2,	// 15:14 [   00b] RW Duration Time for Guest 1 same as above
			r0		:  8,	// 23:16 [  0x00] R  reserved
			GenPurIO	:  8;	// 31:24 [  0xf0] RW General Purpose IO port
	}	GENPURPOSE;

typedef	dword	CODESOURCE;		// bits 0:1 hardwired to 0
typedef	dword	CODETRANSFERCONTROL;	// i have nothing to do with this one, so...
typedef	dword	CODEMEMORY;		// i have nothing to do with this one, so...
typedef	struct
	{
	unsigned	r0		: 16,	// 27: 0 [0x0000] R  reserved
				r1		: 12,
			CodRepIRQ	:  1,	// 28:28 [    0b] RC Code Report Step IRQ
			GIRQ0		:  1,	// 29:29 [    0b] RC GIRQ0 IRQ
			GIRQ1		:  1,	// 30:30 [    0b] RC GIRQ1 IRQ
			r2		:  1;	// 31:31 [    0b] R  reserved
	}	IRQSTATUS;

typedef	struct
	{
	unsigned	r0		: 16,	// 23: 0 [0x0000] R  reserved
				r1		: 8,
			InPinEn		:  1,	// 24:24 [    0b] RW INTA# Pin Enable
				r2	:  3,	// 27:25 [  000b] R  reserved
			CodRepIRQEn	:  1,	// 28:28 [    0b] RW Code Report Step IRQ Enable
			GIRQ0En		:  1,	// 29:29 [    0b] RC GIRQ0 Enable
			GIRQ1En		:  1,	// 30:30 [    0b] RC GIRQ1 Enable
				r3	:  1;	// 31:31 [    0b] R  reserved
	}	IRQCONTROL;

typedef	struct
	{
	unsigned	SCL		:  1,	//  0: 0 [    1b] RW I2C SCL Line
			SDA		:  1,	//  1: 1 [    0b] RW I2C SDA Line
			r0		: 14,
			r1		: 16;	// 31: 2 [0x0000] R  reserved
	}	I2CCONTROL;

/**********************************************************************************************************************/
struct ZR36120
{
 HVIDEOCONTROL			HVideoControl;			// 0x000
 VVIDEOCONTROL			VVideoControl;			// 0x004
 OUTVIDEOCONTROL		OutVideoControl;		// 0x008
 ADRTOPVIDEO			AdrTopVideo;			// 0x00c
 ADRBOTTOMVIDEO			AdrBottomVideo;			// 0x010
 STRIDEGRABCONTROL		StrideGrabControl;		// 0x014
 VIDEOCONTROL			VideoControl;			// 0x018
 ADRTOPVIDEOMASKMAP		AdrTopVideoMaskMap;		// 0x01c
 ADRBOTTOMVIDEOMASKMAP		AdrBottomVideoMaskMap;		// 0x020
 OVERLAYCONTROL			OverlayControl;			// 0x024
 SYSPCICONTROL			SysPCIControl;			// 0x028
 GENPURPOSE			GenPurpose;			// 0x02c
 CODESOURCE			CodeSource;			// 0x030
 CODETRANSFERCONTROL		CodeTransferControl;		// 0x034
 CODEMEMORY			CodeMemory;			// 0x038
 IRQSTATUS			IRQStatus;			// 0x03c
 IRQCONTROL			IRQControl;			// 0x040
 I2CCONTROL			I2CControl;			// 0x044
};
#endif